public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
From: "Rafael J. Wysocki" <rjw@rjwysocki.net>
To: Linux PM <linux-pm@vger.kernel.org>
Cc: LKML <linux-kernel@vger.kernel.org>,
	Alan Stern <stern@rowland.harvard.edu>,
	Ulf Hansson <ulf.hansson@linaro.org>,
	Johan Hovold <johan@kernel.org>,
	Manivannan Sadhasivam <manivannan.sadhasivam@linaro.org>,
	Saravana Kannan <saravanak@google.com>
Subject: [PATCH v1 1/5] PM: sleep: Rename power.async_in_progress to power.work_in_progress
Date: Tue, 25 Feb 2025 17:38:58 +0100	[thread overview]
Message-ID: <3338693.aeNJFYEL58@rjwysocki.net> (raw)
In-Reply-To: <13709135.uLZWGnKmhe@rjwysocki.net>

From: Rafael J. Wysocki <rafael.j.wysocki@intel.com>

Rename the async_in_progress field in struct dev_pm_info to
work_in_progress as after subsequent changes it will mean work in
general rather than just async work.

No functional impact.

Signed-off-by: Rafael J. Wysocki <rafael.j.wysocki@intel.com>
---
 drivers/base/power/main.c |   12 ++++++------
 include/linux/pm.h        |    2 +-
 2 files changed, 7 insertions(+), 7 deletions(-)

--- a/include/linux/pm.h
+++ b/include/linux/pm.h
@@ -679,7 +679,7 @@
 	bool			wakeup_path:1;
 	bool			syscore:1;
 	bool			no_pm_callbacks:1;	/* Owned by the PM core */
-	bool			async_in_progress:1;	/* Owned by the PM core */
+	bool			work_in_progress:1;	/* Owned by the PM core */
 	bool			smart_suspend:1;	/* Owned by the PM core */
 	bool			must_resume:1;		/* Owned by the PM core */
 	bool			may_skip_resume:1;	/* Set by subsystems */




  reply	other threads:[~2025-02-25 16:46 UTC|newest]

Thread overview: 20+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-02-25 16:38 [PATCH v1 0/5] PM: sleep: Improvements of async suspend and resume of devices Rafael J. Wysocki
2025-02-25 16:38 ` Rafael J. Wysocki [this message]
2025-02-25 16:39 ` [PATCH v1 2/5] PM: sleep: Rearrange dpm_async_fn() and async state clearing Rafael J. Wysocki
2025-02-25 16:45 ` [PATCH v1 3/5] PM: sleep: Resume children right after resuming the parent Rafael J. Wysocki
2025-03-13  1:46   ` Saravana Kannan
2025-03-13 15:16     ` Rafael J. Wysocki
2025-02-25 16:45 ` [PATCH v1 4/5] PM: sleep: Start suspending parents and suppliers after subordinate suspend Rafael J. Wysocki
2025-03-13  1:46   ` Saravana Kannan
2025-03-13 13:53     ` Rafael J. Wysocki
2025-02-25 16:45 ` [PATCH v1 5/5] PM: sleep: Make late and noirq suspend of devices more asynchronous Rafael J. Wysocki
2025-03-13  1:47   ` Saravana Kannan
2025-03-13 13:32     ` Rafael J. Wysocki
2025-02-27 15:44 ` [PATCH v1 0/5] PM: sleep: Improvements of async suspend and resume of devices Saravana Kannan
2025-02-27 16:23   ` Rafael J. Wysocki
2025-03-09 22:37     ` Saravana Kannan
2025-03-10 16:01       ` Rafael J. Wysocki
2025-03-10 20:31         ` Saravana Kannan
2025-03-10 21:29           ` Rafael J. Wysocki
2025-03-03 12:06 ` Ulf Hansson
2025-03-03 12:08   ` Rafael J. Wysocki

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=3338693.aeNJFYEL58@rjwysocki.net \
    --to=rjw@rjwysocki.net \
    --cc=johan@kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-pm@vger.kernel.org \
    --cc=manivannan.sadhasivam@linaro.org \
    --cc=saravanak@google.com \
    --cc=stern@rowland.harvard.edu \
    --cc=ulf.hansson@linaro.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
--- a/drivers/base/power/main.c
+++ b/drivers/base/power/main.c
@@ -602,7 +602,7 @@
 	reinit_completion(&dev->power.completion);
 
 	if (is_async(dev)) {
-		dev->power.async_in_progress = true;
+		dev->power.work_in_progress = true;
 
 		get_device(dev);
 
@@ -614,9 +614,9 @@
 	/*
 	 * Because async_schedule_dev_nocall() above has returned false or it
 	 * has not been called at all, func() is not running and it is safe to
 	 * update the async_in_progress flag without extra synchronization.
 	 */
-	dev->power.async_in_progress = false;
+	dev->power.work_in_progress = false;
 	return false;
 }
 
@@ -736,7 +736,7 @@
 		dev = to_device(dpm_noirq_list.next);
 		list_move_tail(&dev->power.entry, &dpm_late_early_list);
 
-		if (!dev->power.async_in_progress) {
+		if (!dev->power.work_in_progress) {
 			get_device(dev);
 
 			mutex_unlock(&dpm_list_mtx);
@@ -876,7 +876,7 @@
 		dev = to_device(dpm_late_early_list.next);
 		list_move_tail(&dev->power.entry, &dpm_suspended_list);
 
-		if (!dev->power.async_in_progress) {
+		if (!dev->power.work_in_progress) {
 			get_device(dev);
 
 			mutex_unlock(&dpm_list_mtx);
@@ -1042,7 +1042,7 @@
 		dev = to_device(dpm_suspended_list.next);
 		list_move_tail(&dev->power.entry, &dpm_prepared_list);
 
-		if (!dev->power.async_in_progress) {
+		if (!dev->power.work_in_progress) {
 			get_device(dev);
 
 			mutex_unlock(&dpm_list_mtx);
@@ -614,9 +614,9 @@
 	 * Because async_schedule_dev_nocall() above has returned false or it
 	 * has not been called at all, func() is not running and it is safe to
-	 * update the async_in_progress flag without extra synchronization.
+	 * update the work_in_progress flag without extra synchronization.
 	 */